package mschmidt.komo;
/*
 * Configures the workbench window.
 * 
 */

import mschmidt.komo.preferences.PreferenceConstants;

import org.eclipse.jface.action.IStatusLineManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ShellAdapter;
import org.eclipse.swt.events.ShellEvent;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Tray;
import org.eclipse.swt.widgets.TrayItem;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.application.ActionBarAdvisor;
import org.eclipse.ui.application.IActionBarConfigurer;
import org.eclipse.ui.application.IWorkbenchWindowConfigurer;
import org.eclipse.ui.application.WorkbenchWindowAdvisor;

public class ApplicationWorkbenchWindowAdvisor extends
		WorkbenchWindowAdvisor {

	private TrayItem trayItem;

	private ApplicationActionBarAdvisor thisActionBarAdvisor;

	/**
	 * Calls configuration classes throughout the WorkbenchAdvisor life cycle.
	 * 
	 * @param configurer - IWorkbenchConfigurer
	 */
	public ApplicationWorkbenchWindowAdvisor(
			final IWorkbenchWindowConfigurer configurer) {
		super(configurer);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.application.
	 * WorkbenchWindowAdvisor#createActionBarAdvisor(
	 * org.eclipse.ui.application.IActionBarConfigurer).
	 */
	@Override
	public final ActionBarAdvisor createActionBarAdvisor(
			final IActionBarConfigurer configurer) {
		thisActionBarAdvisor = new ApplicationActionBarAdvisor(configurer);
		return thisActionBarAdvisor;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.application.WorkbenchWindowAdvisor#preWindowOpen()
	 */
	@Override
	public final void preWindowOpen() {
		IWorkbenchWindowConfigurer configurer = getWindowConfigurer();
		configurer.setInitialSize(new Point(700, 550));
		configurer.setShowCoolBar(true);
		configurer.setShowStatusLine(true);
		configurer.setShowProgressIndicator(true);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.application.WorkbenchWindowAdvisor#openIntro()
	 */
	@Override
	public final void openIntro() {
		super.openIntro();
		if (KomoPlugin.getDefault().getPreferenceStore().getBoolean(
				PreferenceConstants.SHOW_INTRO)) {
			PlatformUI.getWorkbench().getIntroManager().showIntro(null, false);
		}
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.application.WorkbenchWindowAdvisor#postWindowOpen()
	 */
	@Override
	public final void postWindowOpen() {
		final IWorkbenchWindowConfigurer thisConfigurer = getWindowConfigurer();
		final IWorkbenchWindow thisWindow = thisConfigurer.getWindow();
		final IStatusLineManager lineManager = thisConfigurer
				.getActionBarConfigurer().getStatusLineManager();
		lineManager.setMessage("Komo Database Client 1.0");
		// Code to allow application to be minimized to system tray.
		if (KomoPlugin.getDefault().getPreferenceStore().getBoolean(
				PreferenceConstants.TO_TRAY)) {
			trayItem = initTrayItem(thisWindow);
			if (trayItem != null) {
				hookPopupMenu(thisWindow);
				hookMinimize(thisWindow);
			}
		}
	}

	/*
	 * Method to minimize application to tray.
	 */
	private void hookMinimize(final IWorkbenchWindow window) {
		window.getShell().addShellListener(new ShellAdapter() {
			public void shellIconified(final ShellEvent e) {
				window.getShell().setVisible(false);
			}
		});
		trayItem.addListener(SWT.DefaultSelection, new Listener() {
			public void handleEvent(final Event event) {
				Shell shell = window.getShell();
				if (!shell.isVisible()) {
					shell.setVisible(true);
					window.getShell().setMinimized(false);
				}
			}
		});
	}

	/*
	 * Method to access popup menu for minimized tray item.
	 */
	private void hookPopupMenu(final IWorkbenchWindow window) {
		// Add listener for menu pop-up
		trayItem.addListener(SWT.MenuDetect, new Listener() {
			public void handleEvent(final Event event) {
				MenuManager trayMenu = new MenuManager();
				Menu menu = trayMenu.createContextMenu(window.getShell());
				thisActionBarAdvisor.fillTrayItem(trayMenu);
				menu.setVisible(true);
			}
		});
	}

	/*
	 * Method to create tray item.
	 */
	private TrayItem initTrayItem(final IWorkbenchWindow window) {
		final Tray tray = window.getShell().getDisplay().getSystemTray();
		if (tray == null) {
			return null;
		}
		TrayItem trayItem = new TrayItem(tray, SWT.NONE);
		trayItem.setImage(KomoPlugin.getImageDescriptor(ApplicationImages.PG_ICON)
				.createImage());
		trayItem.setToolTipText("Komo Client");
		return trayItem;
	}

	/*
	 *  (non-Javadoc)
	 *  Dispose of the tray item on application shutdown.
	 * @see org.eclipse.ui.application.WorkbenchWindowAdvisor#dispose()
	 */
	public final void dispose() {
		if (trayItem != null) {
			trayItem.dispose();
		}
	}
}
