package mschmidt.komo.datatools;
/**
 * Instances of this object class allow the user to enter a password.
 */

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import mschmidt.komo.KomoPlugin;
import mschmidt.komo.ApplicationImages;
import mschmidt.komo.Application;

public class PasswordDialog extends Dialog {
	// Initialize the variables needed for this class.
	private Text passwordText;
	private String pwString = new String();
	/**
	 * The constructor that creates the dialog.
	 * @param parentShell
	 */
	public PasswordDialog(Shell parentShell, String currPW) {
		super(parentShell);
		pwString = currPW;
	}

	/**
	 * Create contents of the dialog.
	 * @param parent
	 */
	@Override
	protected Control createDialogArea(Composite parent) {
		Composite container = (Composite) super.createDialogArea(parent);
		final GridLayout gridLayout = new GridLayout();
		gridLayout.numColumns = 2;
		container.setLayout(gridLayout);

		final Label passwordLabel = new Label(container, SWT.NONE);
		passwordLabel.setToolTipText("Enter user password");
		passwordLabel.setText("Password");

		passwordText = new Text(container, SWT.PASSWORD | SWT.BORDER);
		passwordText.setText(pwString);
		
		// Disable the OK button if passwordText is a null string.
		passwordText.addModifyListener(new ModifyListener() {
			public void modifyText(final ModifyEvent e) {
				if (passwordText.getText().length() == 0 || passwordText.getText() == null) {
					getButton(IDialogConstants.OK_ID).setEnabled(false);
				} else {
					getButton(IDialogConstants.OK_ID).setEnabled(true);
				}
			}
		});
		passwordText.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
		//
		return container;
	}

	/**
	 * Create contents of the button bar
	 * @param parent
	 */
	@Override
	protected void createButtonsForButtonBar(Composite parent) {
		createButton(parent, IDialogConstants.OK_ID, IDialogConstants.OK_LABEL,
				true);
		createButton(parent, IDialogConstants.CANCEL_ID,
				IDialogConstants.CANCEL_LABEL, false);
	}

	/**
	 * Set the initial size of the dialog.
	 */
	@Override
	protected Point getInitialSize() {
		return new Point(325, 125);
	}
	protected void configureShell(Shell newShell) {
		super.configureShell(newShell);
		newShell.setText("User Password");
		newShell.setImage(KomoPlugin.getImageDescriptor(ApplicationImages.USER_ICON).createImage());
	}

	/*
	 *  (non-Javadoc)
	 *  Allows access to the buttons.
	 * @see org.eclipse.jface.dialogs.Dialog#getButton(int)
	 */
	@Override
	protected Button getButton(int buttonID) {
		return super.getButton(buttonID);
	}

	/*
	 *  (non-Javadoc)
	 *  If a new password has been entered, save it in the
	 *  PasswordManager object created by the Application class.
	 * @see org.eclipse.jface.dialogs.Dialog#buttonPressed(int)
	 */
	@Override
	protected void buttonPressed(int buttonID) {
		if (buttonID == IDialogConstants.OK_ID) {
			String tempString = passwordText.getText();
			if (!pwString.equals(tempString)) {
				Application.dbPassword.setPassword(tempString);
			}
		}
		super.buttonPressed(buttonID);
	}


}
